@@ -20,7 +20,7 @@ from hidebound.exporters.girder_exporter import GirderExporter
 from hidebound.exporters.local_disk_exporter import LocalDiskExporter
 from hidebound.exporters.s3_exporter import S3Exporter
 import hidebound.core.database_tools as db_tools
-import hidebound.core.tools as tools
+import hidebound.core.tools as hbt
 from hidebound.core.logging import ProgressLogger
 # ------------------------------------------------------------------------------
 
@@ -59,7 +59,7 @@ class Database:
             filename, _ = os.path.splitext(filename)
             module = import_module(filename, filepath)  # type: ignore
 
-            specs.extend(module.SPECIFICATIONS)  # type: ignore
+            specs.extend(module.SPECIFICATIONS)
 
         specs = list(set(specs))
         config['specifications'] = specs
@@ -93,16 +93,16 @@ class Database:
 
     def __init__(
         self,
-        root_dir,
-        hidebound_dir,
-        specifications=[],
-        include_regex='',
-        exclude_regex=r'\.DS_Store',
-        write_mode='copy',
-        exporters={},
-        webhooks=[],
+        root_dir,                     # type: Union[str, Path]
+        hidebound_dir,                # type: Union[str, Path]
+        specifications=[],            # type: List[SpecificationBase]
+        include_regex='',             # type: str
+        exclude_regex=r'\.DS_Store',  # type: str
+        write_mode='copy',            # type: str
+        exporters={},                 # type: Dict[str, Any]
+        webhooks=[],                  # type: List[Dict]
     ):
-        # type: (Union[str, Path], Union[str, Path], List[SpecificationBase], str, str, str, Dict[str, Any], List[Dict]) -> None  # noqa E501
+        # type: (...) -> None
         r'''
         Creates an instance of Database but does not populate it with data.
 
@@ -202,8 +202,8 @@ class Database:
                                                             structure
             * asset metadata as json to hb_parent/hidebound/metadata/asset
             * file metadata as json to hb_parent/hidebound/metadata/file
-            * asset log as json to hb_parent/hidebound/logs/asset
-            * file log as json to hb_parent/hidebound/logs/file
+            * asset metadata as single json to hb_parent/hidebound/metadata/asset-chunk
+            * file metadata as single json to hb_parent/hidebound/metadata/file-chunk
 
         Raises:
             RunTimeError: If data has not been initialized.
@@ -216,14 +216,6 @@ class Database:
             msg = 'Data not initialized. Please call update.'
             raise RuntimeError(msg)
 
-        def write_json(obj, filepath):
-            with open(filepath, 'w') as f:
-                json.dump(obj, f)
-
-        def write_log(log, filepath):
-            with open(filepath, 'w') as f:
-                f.write(log)
-
         temp = db_tools._get_data_for_write(
             self.data, self._root, self._hb_root
         )
@@ -231,7 +223,7 @@ class Database:
         if temp is None:
             return self
 
-        file_data, asset_meta, file_meta, asset_log, file_log = temp
+        file_data, asset_meta, file_meta, asset_chunk, file_chunk = temp
 
         # make directories
         for item in temp:
@@ -241,26 +233,26 @@ class Database:
         # write file data
         if self._write_mode == 'move':
             file_data.apply(lambda x: shutil.move(x.source, x.target), axis=1)
-            tools.delete_empty_directories(self._root)
+            hbt.delete_empty_directories(self._root)
         else:
             file_data.apply(lambda x: shutil.copy2(x.source, x.target), axis=1)
         self._logger.info('create: write file data', step=3, total=total)
 
         # write asset metadata
-        asset_meta.apply(lambda x: write_json(x.metadata, x.target), axis=1)
+        asset_meta.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
         self._logger.info('create: write asset metadata', step=4, total=total)
 
         # write file metadata
-        file_meta.apply(lambda x: write_json(x.metadata, x.target), axis=1)
+        file_meta.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
         self._logger.info('create: write file metadata', step=5, total=total)
 
-        # write asset log
-        asset_log.apply(lambda x: write_log(x.metadata, x.target), axis=1)
-        self._logger.info('create: write asset log', step=6, total=total)
+        # write asset chunk
+        asset_chunk.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        self._logger.info('create: write asset chunk', step=6, total=total)
 
-        # write file log
-        file_log.apply(lambda x: write_log(x.metadata, x.target), axis=1)
-        self._logger.info('create: write file log', step=7, total=total)
+        # write file chunk
+        file_chunk.apply(lambda x: hbt.write_json(x.metadata, x.target), axis=1)
+        self._logger.info('create: write file chunk', step=7, total=total)
 
         self._logger.info('create: complete', step=7, total=total)
         return self
@@ -366,8 +358,8 @@ class Database:
         total = 12
         self._logger.info('update', step=0, total=total)
 
-        exclude_re = '|'.join([self._exclude_regex, 'hidebound/logs/progress'])
-        data = tools.directory_to_dataframe(
+        exclude_re = '|'.join([self._exclude_regex, 'hidebound/logs'])
+        data = hbt.directory_to_dataframe(
             self._root,
             include_regex=self._include_regex,
             exclude_regex=exclude_re
@@ -459,9 +451,16 @@ class Database:
             if 'params' in hook and method == 'get':
                 kwargs['params'] = hook['params']
 
+            if 'timeout' in hook:
+                kwargs['timeout'] = hook['timeout']
+
             method = getattr(requests, method)
             response = method(url, headers=headers, **kwargs)
-            self._logger.info(f'call_webhooks: {url}', step=i, total=total)
+            self._logger.info(
+                f'call_webhooks: {url} {response.text}',
+                step=i + 1,
+                total=total
+            )
             yield response
 
     def export(self):
@@ -492,7 +491,7 @@ class Database:
         for i, (key, config) in enumerate(items):
             exporter = lut[key].from_config(config)
             exporter.export(self._hb_root, logger=self._logger)
-            self._logger.info('export: export item', step=i, total=total)
+            self._logger.info(f'export: {key}', step=i + 1, total=total)
 
             # assign instance to exporter_lut for testing
             if self.__exporter_lut is not None:
