@@ -1,9 +1,7 @@
 from typing import Any, Dict, Optional, Tuple, Union
 
 from collections import defaultdict
-from datetime import datetime
 from pathlib import Path
-import json
 import re
 import uuid
 
@@ -14,7 +12,7 @@ import numpy as np
 
 from hidebound.core.parser import AssetNameParser
 from hidebound.core.specification_base import SpecificationBase
-import hidebound.core.tools as tools
+import hidebound.core.tools as hbt
 # ------------------------------------------------------------------------------
 
 
@@ -60,7 +58,7 @@ def _add_specification(data, specifications):
     # set error
     data['file_error'] = np.nan
     mask = data.specification.apply(lambda x: x not in specifications.keys())
-    error = tools.error_to_string(KeyError('Specification not found.'))
+    error = hbt.error_to_string(KeyError('Specification not found.'))
     data.loc[mask, 'file_error'] = error
 
     # parse errors overwrite spec not found
@@ -88,7 +86,7 @@ def _validate_filepath(data):
             row.specification_class().validate_filepath(row.filepath)
             return np.nan
         except ValidationError as e:
-            return tools.error_to_string(e)
+            return hbt.error_to_string(e)
 
     mask = data.file_error.isnull()
     if len(data[mask]) > 0:
@@ -125,7 +123,7 @@ def _add_asset_traits(data):
     '''
     cols = ['asset_path', 'file_traits']
     lut = data[cols].groupby('asset_path', as_index=False)\
-        .agg(lambda x: tools.to_prototype(x.tolist()))\
+        .agg(lambda x: hbt.to_prototype(x.tolist()))\
         .apply(lambda x: x.tolist(), axis=1)\
         .tolist()
     lut = defaultdict(lambda: {}, lut)
@@ -158,7 +156,7 @@ def _validate_assets(data):
     data['asset_error'] = 'null'
     data.loc[mask, 'asset_error'] = data.loc[mask, 'asset_path']\
         .apply(lambda x: lut[x])\
-        .apply(lambda x: tools.error_to_string(x) if x is not None else np.nan)
+        .apply(lambda x: hbt.error_to_string(x) if x is not None else np.nan)
 
     # assign asset_valid column
     data['asset_valid'] = False
@@ -325,12 +323,12 @@ def _get_data_for_write(
         * File data - For writing asset file data to a target filepath.
         * Asset metadata - For writing asset metadata to a target json file.
         * File metadata - For writing file metadata to a target json file.
-        * Asset log - For writing asset log to a target json file.
-        * File log - For writing file log to a target json file.
+        * Asset chunk - For writing asset metadata chunk to a target json file.
+        * File chunk - For writing file metadata chunk to a target json file.
 
     Returns:
-        tuple[DataFrame]: file_data, asset_metadata, file_metadata, asset_log,
-            file_log.
+        tuple[DataFrame]: file_data, asset_metadata, file_metadata, asset_chunk,
+            file_chunk.
     '''
     # TODO: flatten file_traits and flatten asset_traits
     # get valid asset data
@@ -344,7 +342,6 @@ def _get_data_for_write(
     source_dir = Path(source_dir).absolute().as_posix()
     data_dir = Path(target_dir, 'content').absolute().as_posix()
     meta_dir = Path(target_dir, 'metadata').absolute().as_posix()
-    log_dir = Path(target_dir, 'logs').absolute().as_posix()
 
     # add asset id
     keys = data.asset_path.unique().tolist()
@@ -391,7 +388,7 @@ def _get_data_for_write(
         filepath_relative='filepaths_relative',
     )
     keys = asset_meta.columns.tolist()
-    for i, row in asset_meta.iterrows():
+    for _, row in asset_meta.iterrows():
         vals = row.tolist()
         item = dict(zip(keys, vals))
         item = {lut[k]: item[k] for k in lut.keys()}
@@ -409,9 +406,8 @@ def _get_data_for_write(
         del item['file_traits']
 
         # replace asset root
-        item['asset_path'] = Path(
-            data_dir, item['asset_path_relative']
-        ).as_posix()
+        item['asset_path'] = Path(data_dir, item['asset_path_relative']) \
+            .as_posix()
 
         meta.append(item)
     asset_meta['metadata'] = meta
@@ -433,21 +429,21 @@ def _get_data_for_write(
         .apply(lambda x: Path(meta_dir, 'file', x + '.json').as_posix())
     file_meta = file_meta[['metadata', 'target']]
 
-    # create asset log
-    now = datetime.now().strftime('%Y-%m-%dT-%H-%M-%S')
-    asset_log = DataFrame()
-    asset_log['target'] = [Path(
-        log_dir, 'asset', f'hidebound-asset-log_{now}.json'
-    ).as_posix()]
-    log = asset_meta.metadata.apply(json.dumps).tolist()
-    asset_log['metadata'] = ['[\n' + ',\n'.join(log) + '\n]']
+    # get time
+    now = hbt.time_string()
 
-    # create file log
-    file_log = DataFrame()
-    file_log['target'] = [Path(
-        log_dir, 'file', f'hidebound-file-log_{now}.json'
+    # create asset chunk
+    asset_chunk = DataFrame()
+    asset_chunk['metadata'] = [asset_meta.metadata.tolist()]
+    asset_chunk['target'] = [Path(
+        meta_dir, 'asset-chunk', f'hidebound-asset-chunk_{now}.json'
     ).as_posix()]
-    log = file_meta.metadata.apply(json.dumps).tolist()
-    file_log['metadata'] = ['[\n' + ',\n'.join(log) + '\n]']
 
-    return file_data, asset_meta, file_meta, asset_log, file_log
+    # create file chunk
+    file_chunk = DataFrame()
+    file_chunk['metadata'] = [file_meta.metadata.tolist()]
+    file_chunk['target'] = [Path(
+        meta_dir, 'file-chunk', f'hidebound-file-chunk_{now}.json'
+    ).as_posix()]
+
+    return file_data, asset_meta, file_meta, asset_chunk, file_chunk
