@@ -1,10 +1,9 @@
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Union
 
 from pathlib import Path
 
-from girder_client import HttpError
 from schematics import Model
-from schematics.types import IntType, StringType, URLType
+from schematics.types import IntType, ListType, StringType, URLType
 import girder_client
 
 from hidebound.exporters.exporter_base import ExporterBase
@@ -24,6 +23,8 @@ class GirderConfig(Model):
             Options: folder, collection
         host (str, optional): Docker host URL address. Default: http://0.0.0.0
         port (int, optional): Docker host port. Default: 8180.
+        metadata_types (list, optional): List of metadata types for export.
+            Default: [asset, file].
     '''
     api_key = StringType(required=True)  # type: StringType
     root_id = StringType(required=True)  # type: StringType
@@ -41,6 +42,11 @@ class GirderConfig(Model):
             lambda x: vd.is_gt(x, 1023),
         ]
     )  # type: IntType
+    metadata_types = ListType(
+        StringType(validators=[vd.is_metadata_type]),
+        required=True,
+        default=['asset', 'file']
+    )
 
 
 class GirderExporter(ExporterBase):
@@ -74,8 +80,9 @@ class GirderExporter(ExporterBase):
         host='http://0.0.0.0',
         port=8180,
         client=None,
+        metadata_types=['asset', 'file'],
     ):
-        # type: (str, str, str, str, int, Any) -> None
+        # type: (str, str, str, str, int, Any, List[str]) -> None
         '''
         Constructs a GirderExporter instances and creates a Girder client.
 
@@ -90,6 +97,9 @@ class GirderExporter(ExporterBase):
             port (int, optional): Docker host port. Default: 8180.
             client (object, optional): Client instance, for testing.
                 Default: None.
+            metadata_types (list[str], optional): Metadata types to export.
+                Default: [asset, file].
+    ):
 
         Raises:
             DataError: If config is invalid.
@@ -97,12 +107,19 @@ class GirderExporter(ExporterBase):
         # sudo ip addr show docker0 | grep inet | grep docker0 | awk '{print $2}' | sed 's/\/.*//'
         # will give you the ip address of the docker network which binds to
         # localhost
+
+        metadata_types = list(
+            filter(lambda x: x in ['asset', 'file'], metadata_types)
+        )
+        super().__init__(metadata_types=metadata_types)
+
         config = dict(
             api_key=api_key,
             root_id=root_id,
             root_type=root_type,
             host=host,
             port=port,
+            metadata_types=metadata_types,
         )
         config = GirderConfig(config)
         config.validate()
@@ -165,37 +182,10 @@ class GirderExporter(ExporterBase):
             parentType='folder',
         )
 
-    def _export_asset(self, metadata):
-        # type: (Dict) -> None
+    def _export_content(self, metadata):
+        # type: (dict) -> Any
         '''
-        Export asset metadata to Girder.
-        Metadata must contain these fields:
-            * asset_type
-            * asset_path_relative
-
-        Args:
-            metadata (dict): Asset metadata.
-
-        Raises:
-            HttpError: If final asset directory already exists.
-        '''
-        if metadata['asset_type'] != 'file':
-            try:
-                self._export_dirs(
-                    metadata['asset_path_relative'],
-                    metadata=metadata
-                )
-            except HttpError as e:
-                msg = f"{metadata['asset_path_relative']} directory already "
-                msg += 'exists. ' + e.responseText
-                e.responseText = msg
-                e.args = [msg]
-                raise e
-
-    def _export_file(self, metadata):
-        # type: (Dict) -> Any
-        '''
-        Export file metadata to Girder.
+        Export file content and metadata to Girder.
         Metadata must contain these fields:
             * filepath_relative
             * filename
@@ -215,32 +205,64 @@ class GirderExporter(ExporterBase):
         # folder error will always be raised before duplicate file conflict is
         # encountered, so don't test for duplicate files within directory
 
+        meta = metadata
+        if 'file' not in self._metadata_types:
+            meta = {}
+
         response = self._client.createItem(
             response['_id'],
             filename,
-            metadata=metadata,
+            metadata=meta,
             reuseExisting=True,
         )
         response = self._client\
             .uploadFileToItem(response['_id'], metadata['filepath'])
         return response
 
-    def _export_asset_log(self, metadata):
-        # type: (Dict[str, str]) -> None
+    def _export_asset(self, metadata):
+        # type: (dict) -> None
         '''
-        Exports content from asset log in hidebound/logs/asset.
+        Export asset metadata to Girder.
+        Metadata must contain these fields:
+            * asset_type
+            * asset_path_relative
 
         Args:
-            metadata (dict): Asset log.
+            metadata (dict): Asset metadata.
+        '''
+        if metadata['asset_type'] != 'file':
+            self._export_dirs(
+                metadata['asset_path_relative'],
+                metadata=metadata,
+                exists_ok=True,
+            )
+
+    def _export_file(self, metadata):
+        # type: (dict) -> None
+        '''
+        Exports content from file metadata in hidebound/metadata/file.
+
+        Args:
+            metadata (dict): File metadata.
         '''
         pass
 
-    def _export_file_log(self, metadata):
-        # type: (Dict[str, str]) -> None
+    def _export_asset_chunk(self, metadata):
+        # type: (List[dict]) -> None
         '''
-        Exports content from file log in hidebound/logs/file.
+        Exports content from asset log in hidebound/metadata/asset-chunk.
 
         Args:
-            metadata (dict): File log.
+            metadata (list[dict]): Asset metadata chunk.
+        '''
+        pass
+
+    def _export_file_chunk(self, metadata):
+        # type: (List[dict]) -> None
+        '''
+        Exports content from file log in hidebound/metadata/file-chunk.
+
+        Args:
+            metadata (list[dict]): File metadata chunk.
         '''
         pass
