@@ -1,18 +1,18 @@
-from typing import Dict
+from typing import List
 
 from io import BytesIO
 import json
 
-from schematics import Model
 from schematics.types import StringType
 import boto3 as boto
 
-from hidebound.exporters.exporter_base import ExporterBase
+from hidebound.exporters.exporter_base import ExporterBase, ExporterConfigBase
+import hidebound.core.tools as tools
 import hidebound.core.validators as vd
 # ------------------------------------------------------------------------------
 
 
-class S3Config(Model):
+class S3Config(ExporterConfigBase):
     '''
     A class for validating configurations supplied to S3Exporter.
 
@@ -35,7 +35,7 @@ class S3Config(Model):
 class S3Exporter(ExporterBase):
     @staticmethod
     def from_config(config):
-        # type: (Dict) -> S3Exporter
+        # type: (dict) -> S3Exporter
         '''
         Construct a S3Exporter from a given config.
 
@@ -56,8 +56,9 @@ class S3Exporter(ExporterBase):
         secret_key,
         bucket,
         region,
+        metadata_types=['asset', 'file', 'asset-chunk', 'file-chunk'],
     ):
-        # type: (str, str, str, str) -> None
+        # type: (str, str, str, str, List[str]) -> None
         '''
         Constructs a S3Exporter instances and creates a bucket with given name
         if it does not exist.
@@ -67,15 +68,20 @@ class S3Exporter(ExporterBase):
             secret_key (str): AWS secret key.
             bucket (str): AWS bucket name.
             region (str): AWS region.
+            metadata_types (list, optional): List of metadata types for export.
+                Default: [asset, file, asset-chunk, file-chunk].
 
         Raises:
             DataError: If config is invalid.
         '''
+        super().__init__(metadata_types=metadata_types)
+
         config = dict(
             access_key=access_key,
             secret_key=secret_key,
             bucket=bucket,
             region=region,
+            metadata_types=metadata_types,
         )
         S3Config(config).validate()
         # ----------------------------------------------------------------------
@@ -91,8 +97,21 @@ class S3Exporter(ExporterBase):
                 CreateBucketConfiguration={'LocationConstraint': region}
             )
 
+    def _export_content(self, metadata):
+        # type: (dict) -> None
+        '''
+        Exports metadata from single JSON file in hidebound/metadata/file.
+
+        Args:
+            metadata (dict): File metadata.
+        '''
+        self._bucket.upload_file(
+            metadata['filepath'],
+            'hidebound/content/' + metadata['filepath_relative'],
+        )
+
     def _export_asset(self, metadata):
-        # type: (Dict) -> None
+        # type: (dict) -> None
         '''
         Exports metadata from single JSON file in hidebound/metadata/asset.
 
@@ -105,7 +124,7 @@ class S3Exporter(ExporterBase):
         )
 
     def _export_file(self, metadata):
-        # type: (Dict) -> None
+        # type: (dict) -> None
         '''
         Exports metadata from single JSON file in hidebound/metadata/file.
 
@@ -116,33 +135,33 @@ class S3Exporter(ExporterBase):
             BytesIO(json.dumps(metadata, indent=4).encode('utf-8')),
             'hidebound/metadata/file/' + metadata['file_id'] + '.json',
         )
-        self._bucket.upload_file(
-            metadata['filepath'],
-            'hidebound/content/' + metadata['filepath_relative'],
-        )
 
-    def _export_asset_log(self, metadata):
-        # type: (Dict[str, str]) -> None
+    def _export_asset_chunk(self, metadata):
+        # type: (List[dict]) -> None
         '''
-        Exports content from single asset log in hidebound/logs/asset.
+        Exports list of asset metadata to a single file in
+        hidebound/metadata/asset-chunk.
 
         Args:
-            metadata (dict): Asset log.
+            metadata (list[dict]): Asset metadata.
         '''
+        now = tools.time_string()
         self._bucket.upload_fileobj(
-            BytesIO(metadata['content'].encode('utf-8')),
-            'hidebound/logs/asset/' + metadata['filename'],
+            BytesIO(json.dumps(metadata).encode('utf-8')),
+            f'hidebound/metadata/asset-chunk/hidebound-asset-chunk_{now}.json',
         )
 
-    def _export_file_log(self, metadata):
-        # type: (Dict[str, str]) -> None
+    def _export_file_chunk(self, metadata):
+        # type: (List[dict]) -> None
         '''
-        Exports content from single file log in hidebound/logs/file.
+        Exports list of file metadata to a single file in
+        hidebound/metadata/file-chunk.
 
         Args:
-            metadata (dict): Asset log.
+            metadata (list[dict]): File metadata.
         '''
+        now = tools.time_string()
         self._bucket.upload_fileobj(
-            BytesIO(metadata['content'].encode('utf-8')),
-            'hidebound/logs/file/' + metadata['filename'],
+            BytesIO(json.dumps(metadata).encode('utf-8')),
+            f'hidebound/metadata/file-chunk/hidebound-file-chunk_{now}.json',
         )
