@@ -1,6 +1,7 @@
 from typing import Any, Dict, Tuple, Union
 
 from pathlib import Path
+from pprint import pformat
 import base64
 import json
 import os
@@ -8,6 +9,7 @@ import traceback
 
 import flask
 import jinja2
+import jsoncomment as jsonc
 import lunchbox.tools as lbt
 # ------------------------------------------------------------------------------
 
@@ -75,7 +77,14 @@ def error_to_response(error):
     Returns:
         flask.Response: Flask response.
     '''
-    args = ['    ' + str(x) for x in error.args]  # type: Any
+    args = []  # type: Any
+    for arg in error.args:
+        if hasattr(arg, 'items'):
+            for key, val in arg.items():
+                args.append(pformat({key: pformat(val)}))
+        else:
+            args.append(str(arg))
+    args = ['    ' + x for x in args]
     args = '\n'.join(args)
     klass = error.__class__.__name__
     msg = f'{klass}(\n{args}\n)'
@@ -96,26 +105,28 @@ def error_to_response(error):
 def setup_hidebound_directory(root, config_path=None):
     # type: (Union[str, Path], Union[str, Path, None]) -> Tuple[Dict, str]
     '''
-    Creates [root]/hidebound and [root]/hidebound/specifications
-    directories. Writes a default hidebound config to
-    [root]/hidebound/hidebound_config.json if one does not exist.
+    Creates [root]/hidebound and [root]/hidebound/config directories.
+    Writes a default hidebound config to
+    [root]/hidebound/config/hidebound_config.json if one does not exist.
 
     Args:
         root (str or Path): Root directory of hidebound data.
         config_path (str or Path, optional): Filepath of config data to be
-            written to [root]/hidebound/hideebiund_config.json. Default: None.
+            written to [root]/hidebound/config/hidebound_config.json.
+            Default: None.
 
     Return:
         tuple[dict, str]: Config data and filepath.
     '''
     root = Path(root)
-    hb_root = Path(root, 'hidebound')
-    os.makedirs(hb_root, exist_ok=True)
-    os.makedirs(Path(hb_root, 'specifications'), exist_ok=True)
+    hb_root = Path(root, 'hidebound').as_posix()
+    config_dir = Path(hb_root, 'config')
+    os.makedirs(config_dir, exist_ok=True)
+    target = Path(config_dir, 'hidebound_config.json').as_posix()
 
     config = {
         'root_directory': Path(root, 'projects').as_posix(),
-        'hidebound_directory': hb_root.as_posix(),
+        'hidebound_directory': hb_root,
         'specification_files': [],
         'include_regex': '',
         'exclude_regex': r'\.DS_Store',
@@ -123,14 +134,12 @@ def setup_hidebound_directory(root, config_path=None):
     }
     if config_path is not None:
         with open(config_path) as f:
-            config = json.load(f)
+            config = jsonc.JsonComment().load(f)
 
-    config_path = Path(root, 'hidebound', 'hidebound_config.json')
-    if not config_path.is_file():
-        with open(config_path, 'w') as f:
-            json.dump(config, f, indent=4, sort_keys=True)
+    with open(target, 'w') as f:
+        json.dump(config, f, indent=4, sort_keys=True)
 
-    return config, config_path.as_posix()
+    return config, target
 
 
 # ERRORS------------------------------------------------------------------------
